@@ -41,7 +41,12 @@
 #ifndef STATEMACHINE_H
 #define STATEMACHINE_H
 
-#include <QtCore>
+#include <QAbstractAnimation>
+#include <QAbstractTransition>
+#include <QEvent>
+#include <QPropertyAnimation>
+#include <QState>
+#include <QStateMachine>
 
 class StateSwitchEvent: public QEvent
 {
@@ -75,13 +80,13 @@ public:
 
 protected:
 
-    virtual bool eventTest(QEvent *event)
+    bool eventTest(QEvent *event) override
     {
         return (event->type() == QEvent::Type(StateSwitchEvent::StateSwitchType))
                && (static_cast<StateSwitchEvent *>(event)->id() == m_id);
     }
 
-    virtual void onTransition(QEvent *) {}
+    void onTransition(QEvent *) override {}
 
 private:
     int m_id;
